#' A standard UCR Gun Point dataset from http://www.cs.ucr.edu/~eamonn/time_series_data
#'
#' @format A four-elements list containing train and test data along with their labels
#' \itemize{
#'   \item labels_train: the training data labels, correspond to data matrix rows
#'   \item data_train: the training data matrix, each row is a time series instance
#'   \item labels_test: the test data labels, correspond to data matrix rows
#'   \item data_test: the test data matrix, each row is a time series instance
#' }
"Gun_Point"

#' A standard UCR Cylinder-Bell-Funnel dataset from http://www.cs.ucr.edu/~eamonn/time_series_data
#'
#' @format A four-elements list containing train and test data along with their labels
#' \itemize{
#'   \item labels_train: the training data labels, correspond to data matrix rows
#'   \item data_train: the training data matrix, each row is a time series instance
#'   \item labels_test: the test data labels, correspond to data matrix rows
#'   \item data_test: the test data matrix, each row is a time series instance
#' }
"CBF"

#' A PHYSIONET dataset
#'
#' @format A vector of numeric values
"ecg0606"
